@@ -2,9 +2,6 @@
 #
 # Univention Directory Manager
 #
-# Like what you see? Join us!
-# https://www.univention.com/about-us/careers/vacancies/
-#
 # SPDX-FileCopyrightText: 2025 Univention GmbH
 # SPDX-License-Identifier: AGPL-3.0-only
 """Authorization for UDM access."""
@@ -49,7 +46,7 @@ def get_user(lo, user_dn: str):
 def get_user_roles(obj) -> list[str]:
     if hasattr(obj, 'open_guardian'):
         obj.open_guardian()
-    role_set = set(obj.get("guardianInheritedRoles", []) + obj.get("guardianRoles", []))
+    role_set = set(obj.get('guardianInheritedRoles', []) + obj.get('guardianRoles', []))
     return role_set
 
 
@@ -109,6 +106,8 @@ class Authorization:
         actor_dn = lo.binddn
         # FIXME: memory leak, use weakref.ref() ?
         actor = get_user(cls.get_privileged_connection(), actor_dn)
+        return lambda: (actor, get_user_roles(actor))
+        # FIXME: don't cache actor roles as we don't know when to invalidate the cache. Roles of groups can be changed at any time.
         if cls._user_roles_cache.get(actor_dn) is None:
             cls._user_roles_cache[actor_dn] = (actor, get_user_roles(actor))
         return lambda: cls._user_roles_cache[actor_dn]
@@ -278,6 +277,7 @@ class Authorization:
 
         # FIXME: deepcopy is expensive
         import copy
+
         moved_obj = copy.deepcopy(obj)
         moved_obj.dn = dest
 
@@ -377,7 +377,9 @@ class Authorization:
             targeted_permissions_to_check=[f'udm:{mod}:{action}'],
         )
 
-        writeable_attributes = self._get_writeable_properties(permissions_result['general_permissions'] | permissions_result['target_permissions'][0]['permissions'], mod, set(obj.descriptions))
+        writeable_attributes = self._get_writeable_properties(
+            permissions_result['general_permissions'] | permissions_result['target_permissions'][0]['permissions'], mod, set(obj.descriptions),
+        )
         all_allowed = allowed and self._is_all_writeable(writeable_attributes, obj.module, changed_properties)
         if not all_allowed:
             auth_log(action, actor, targets[0], general=allowed, changed_properties=changed_properties)
