@@ -5,8 +5,6 @@
 
 from __future__ import annotations
 
-from logging import getLogger
-
 import ldap
 
 import univention.admin.handlers
@@ -14,8 +12,6 @@ import univention.admin.localization
 from univention.admin.layout import Group, Tab
 
 
-log = getLogger('ADMIN')
-
 translation = univention.admin.localization.translation('univention.admin.handlers.mail')
 _ = translation.translate
 
@@ -199,7 +195,7 @@ class object(univention.admin.handlers.simpleLdap):
         rewrite_acl = False
         new_acls_tmp = []
         for attr in ['sharedFolderUserACL', 'sharedFolderGroupACL']:
-            log.debug('ACLs: %s', str(self[attr]))
+            self.log.debug('current ACLs', attr=attr, value=self[attr])
             if self.hasChanged(attr):
                 rewrite_acl = True
                 # re-use regular expressions from syntax definitions
