@@ -1,7 +1,3 @@
-#
-# Like what you see? Join us!
-# https://www.univention.com/about-us/careers/vacancies/
-#
 # SPDX-FileCopyrightText: 2004-2025 Univention GmbH
 # SPDX-License-Identifier: AGPL-3.0-only
 
@@ -27,6 +23,7 @@ short_description = _('Printer share: Printer group')
 object_name = _('Printer share group')
 object_name_plural = _('Printer share groups')
 long_description = ''
+# fmt: off
 options = {
     'default': univention.admin.option(
         short_description=short_description,
@@ -81,6 +78,7 @@ mapping.register('name', 'cn', None, univention.admin.mapping.ListToString)
 mapping.register('spoolHost', 'univentionPrinterSpoolHost', encoding='ASCII')
 mapping.register('sambaName', 'univentionPrinterSambaName', None, univention.admin.mapping.ListToString)
 mapping.register('groupMember', 'univentionPrinterGroupMember')
+# fmt: on
 
 
 class object(univention.admin.handlers.simpleLdap):
@@ -105,7 +103,9 @@ class object(univention.admin.handlers.simpleLdap):
                 if member_cn == self.info['name']:
                     rm_attrib.append(pg_dn)
                     if len(member_list['univentionPrinterGroupMember']) < 2:
-                        raise univention.admin.uexceptions.emptyPrinterGroup(_('%(name)s is the last member of the printer group %(group)s. ') % {'name': self.info['name'], 'group': member_list['cn'][0].decode('UTF-8')})
+                        raise univention.admin.uexceptions.emptyPrinterGroup(
+                            _('%(name)s is the last member of the printer group %(group)s. ') % {'name': self.info['name'], 'group': member_list['cn'][0].decode('UTF-8')},
+                        )
 
         printergroup_module = univention.admin.modules._get('shares/printergroup')
         for rm_dn in rm_attrib:
